@@ -187,14 +187,20 @@
                  "krige.conv: model with mean defined by covariates provided by the user"))
     cat("\n")
   }
-  trend.d <- unclass(trend.spatial(trend=krige$trend.d, geodata = geodata))
+  if(class(krige$trend.d) == "trend.spatial")
+    trend.d <- unclass(krige$trend.d)
+  else
+    trend.d <- unclass(trend.spatial(trend=krige$trend.d, geodata = geodata))
   if (nrow(trend.d) != nrow(coords)) 
-      stop("coords and trend.d have incompatible sizes")
+    stop("coords and trend.d have incompatible sizes")
   beta.size <- ncol(trend.d)
   if(beta.prior == "deg")
     if(beta.size != length(beta))
       stop("size of mean vector is incompatible with trend specified") 
-  trend.l <- unclass(trend.spatial(trend=krige$trend.l, geodata = list(coords = locations)))
+  if(class(krige$trend.l) == "trend.spatial")
+    trend.l <- unclass(krige$trend.l)
+  else
+    trend.l <- unclass(trend.spatial(trend=krige$trend.l, geodata = list(coords = locations)))
   if (nrow(trend.l) != nrow(locations)) 
     stop("locations and trend.l have incompatible sizes")
   if(beta.size > 1)
