@@ -40,15 +40,15 @@ Real corrfctvalue(Real phi, Real kappa, Real h, Integer cornr)
      
      Correlation functions implemented and their numbers
      
-     1: PURE NUGGET
-     2: EXPONENTIAL
-     3: SPHERICAL
-     4: GAUSSIAN
-     5: WAVE (hole effect)
-     6: CUBIC
-     7: POWER
-     8: POWERED EXPONENTIAL
-     9: CAUCHY
+      1: PURE NUGGET
+      2: EXPONENTIAL
+      3: SPHERICAL
+      4: GAUSSIAN
+      5: WAVE (hole effect)
+      6: CUBIC
+      7: POWER
+      8: POWERED EXPONENTIAL
+      9: CAUCHY
      10: GNEITING
      11: CIRCULAR
      12: MATERN
@@ -58,7 +58,10 @@ Real corrfctvalue(Real phi, Real kappa, Real h, Integer cornr)
      "cor.number"
   */
   
-  Real hphi, hphi2, hphi4;
+  Real hphi; 
+  Real hphi2;
+  Real hphi4;
+
   if(h==0) return 1;
   else{  
     hphi  = h/phi ;
@@ -79,7 +82,7 @@ Real corrfctvalue(Real phi, Real kappa, Real h, Integer cornr)
       return exp(-(hphi * hphi)) ;
       break;
     case 5: /* wave (hole effect) */
-      return hphi*sin(hphi) ;
+      return sin(hphi)/hphi ;
       break;
     case 6: /* cubic */
       if (h < phi){
@@ -101,8 +104,9 @@ Real corrfctvalue(Real phi, Real kappa, Real h, Integer cornr)
       return R_pow((1 + (hphi * hphi)), (-kappa)) ;
       break;
     case 10:  /* gneiting */
-      hphi4 = 1 - hphi;
-      if (hphi4 > 0) hphi4 = R_pow(hphi4, 8);
+      hphi = 0.301187465825 * hphi ;
+      hphi4 = 1 - hphi ;
+      if (hphi4 > 0) hphi4 = R_pow(hphi4, 8) ;
       else hphi4 = 0 ;
       hphi2 = hphi * hphi ;
       return (1 + 8 * hphi + 25 * hphi2 + 32 * (hphi2 * hphi)) * hphi4 ;
@@ -132,15 +136,20 @@ void veccorrval(Real *phi, Real *kappa, Real *h, Integer *n,
 		Integer *cornr, Real *res)  
 {
   Integer j ;
-  Real cmax = 0;
+  Real cmax = 0, A;
   
   for (j=0; j<(*n); j++){
     res[j] = corrfctvalue(*phi, *kappa, h[j], *cornr)  ;
     if(*cornr == 7) cmax = fmax2(cmax, res[j]) ;
   }
   if(*cornr == 7){
+    A = (cmax/M_SQRT_PI) * gammafn((1 + *phi)/2) * gammafn(1-(*phi/2)) *
+      gammafn(*phi + 1.5)/(gammafn(1 + *phi) * gammafn(1.5));
+    cmax = 0 ;
     for (j=0; j<(*n); j++){
-      res[j] = (cmax - res[j])/cmax  ;
+      res[j] = A - res[j] ;
+      cmax = fmax2(cmax, res[j]) ;
+      res[j] = res[j]/cmax;
     }
   }
   return ;
